
Glance Store Drivers
====================

Glance store supports several different drivers. These drivers live
within the library's code base and they are maintained by either
members of the Glance community or OpenStack in general. Please, find
below the table of supported drivers and maintainers:

.. list-table::
   :header-rows: 1

   * - Driver
     - Maintainer
     - Email
     - IRC Nick
   * - File System
     - Glance Team
     - openstack-dev@lists.openstack.org
     - openstack-glance
   * - HTTP
     - Glance Team
     - openstack-dev@lists.openstack.org
     - openstack-glance
   * - RBD
     - Fei Long Wang
     - flwang@catalyst.net.nz
     - flwang
   * - Cinder
     - Tomoki Sekiyama
     - tomoki.sekiyama@gmail.com
     -
   * - Swift
     - Matthew Oliver
     - matt@oliver.net.au
     - mattoliverau
   * - VMware
     - Sabari Murugesan
     - smurugesan@vmware.com
     - sabari
   * - Sheepdog
     - YAMADA Hideki
     - yamada.hideki@lab.ntt.co.jp
     - yamada-h
